Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(105)

Unified Diff: remoting/protocol/client_control_dispatcher.h

Issue 9646013: Add the plumbing that will carry a clipboard item from a chromoting client to a host. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix remoting_simple_host. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/proto/internal.proto ('k') | remoting/protocol/client_control_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/client_control_dispatcher.h
diff --git a/remoting/protocol/client_control_dispatcher.h b/remoting/protocol/client_control_dispatcher.h
index 2550a2cb49f684b3bf55df68f5c12a14d263ef78..df434200ae30eb9ad5c92221c66c477b0830c92e 100644
--- a/remoting/protocol/client_control_dispatcher.h
+++ b/remoting/protocol/client_control_dispatcher.h
@@ -7,6 +7,7 @@
#include "base/memory/ref_counted.h"
#include "remoting/protocol/channel_dispatcher_base.h"
+#include "remoting/protocol/clipboard_stub.h"
#include "remoting/protocol/host_stub.h"
#include "remoting/protocol/message_reader.h"
@@ -19,13 +20,18 @@ class BufferedSocketWriter;
class Session;
// ClientControlDispatcher dispatches incoming messages on the control
-// channel to ClientStub, and also implements HostStub for outgoing
-// messages.
-class ClientControlDispatcher : public ChannelDispatcherBase, public HostStub {
+// channel to ClientStub, and also implements ClipboardStub and HostStub for
+// outgoing messages.
+class ClientControlDispatcher : public ChannelDispatcherBase,
+ public ClipboardStub,
+ public HostStub {
public:
ClientControlDispatcher();
virtual ~ClientControlDispatcher();
+ // ClipboardStub implementation.
+ virtual void InjectClipboardEvent(const ClipboardEvent& event) OVERRIDE;
+
// Sets ClientStub that will be called for each incoming control
// message. Doesn't take ownership of |client_stub|. It must outlive
// this dispatcher.
« no previous file with comments | « remoting/proto/internal.proto ('k') | remoting/protocol/client_control_dispatcher.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698